# Production and Sandbox Workspaces
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/production-and-sandbox-workspaces#introduction)
  * [Difference Between a Production and a Sandbox Workspace](https://help.sap.com/docs/leanix/ea/production-and-sandbox-workspaces#difference-between-a-production-and-a-sandbox-workspace)
  * [Production Workspace Best Practices](https://help.sap.com/docs/leanix/ea/production-and-sandbox-workspaces#production-workspace-best-practices)
  * [Sandbox Workspace Best Practices](https://help.sap.com/docs/leanix/ea/production-and-sandbox-workspaces#sandbox-workspace-best-practices)


This guide outlines best practices and scenarios for using production and sandbox workspaces in SAP LeanIX, helping you make informed decisions on when to rely on each workspace type.
